@@ -1,13 +1,13 @@
 # @Author: chunyang.xu
 # @Email:  398745129@qq.com
 # @Date:   2020-06-03 10:31:52
-# @Last Modified time: 2020-06-17 21:08:30
+# @Last Modified time: 2022-08-11 10:05:45
 # @github: https://github.com/longfengpili
 
 #!/usr/bin/env python3
 # -*- coding:utf-8 -*-
 
-from .base import DBCommon
+from .base import DBMixin
 from .fileexec import DBFileExec
 
-__all__ = ['DBCommon', 'DBFileExec']
+__all__ = ['DBMixin', 'DBFileExec']
